@@ -24,9 +24,30 @@ cat.description <- function(field, value, file='') {
     value_string <- paste("    ", value, collapse = ",\n", sep = "")
     out <- paste(field, ":\n", value_string, sep = "")
   } else {
-    width <- if (individual_lines) 0 else 60
-    out <- strwrap(sprintf('%s: %s', field, value), exdent=4, width = width)    
+    width <- if (individual_lines) 0 else 80
+    out <- wrap_field_if_necessary(field, value, wrap.threshold = width)    
   }
 
   cat(out, sep='\n', file=file, append=TRUE)
 }
+
+# Determine whether a given field is too long and should be text-wrapped
+wrap_field_if_necessary <- function(field, value, wrap.threshold) {
+   text <- simulate_formatted_text(field, value)
+   longest.line <- max(str_length(text))
+   
+   if (longest.line > wrap.threshold) {
+     text <- str_wrap(str_c(field, ": ", value), exdent = 4, width = wrap.threshold)
+   }
+   
+   return(text)
+}
+
+# Simulate what was probably the user's intended field formatting
+simulate_formatted_text <- function(field, value) {
+  text     <- str_split(str_c(field, ": ", value), "\n")[[1]]
+  text[-1] <- str_c("    ", text[-1]) # indents all *but* the first line
+  
+  return(text)
+}
+
